<?php
/**
 * Enqueue scripts and styles for theme usage.
 *
 * @since      2.0
 * @author     Satrya <satrya@satrya.me>
 * @copyright  Copyright (c) 2012 - 2014, Satrya
 * @link       http://satrya.me/wordpress-themes/tiga/
 * @license    http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

/* Enqueue styles & scripts. */
add_action( 'wp_enqueue_scripts', 'tiga_enqueue_scripts' );

/* Deregister wp-pagenavi plugin style. */
add_action( 'wp_print_styles', 'tiga_deregister_styles', 100 );

/* Comment reply js */
add_action( 'comment_form_before', 'tiga_enqueue_comment_reply_script' );

/* Loads HTML5 Shiv. */
add_action( 'wp_head', 'tiga_html5_script', 1 );

/**
 * Enqueue scripts
 *
 * @since 0.0.1
 */
function tiga_enqueue_scripts() {
	global $post;

	/* Load dashicons. */
	wp_enqueue_style( 'dashicons' );

	/* Load custom google fonts. */
	wp_enqueue_style( 'tiga-font', 'http://fonts.googleapis.com/css?family=Francois+One|Open+Sans:400italic,400,700', null, TIGA_VERSION, 'all' );

	/* Load main stylesheet. */
	wp_enqueue_style( 'tiga-style', get_stylesheet_uri(), null, TIGA_VERSION, 'all' );

	/* Load jquery script for attachment page. */
	if ( is_singular() && wp_attachment_is_image( $post->ID ) ) {
		wp_enqueue_script( 'tiga-keyboard-image-navigation', trailingslashit( TIGA_JS ) . 'keyboard-image-navigation.js', array( 'jquery' ), TIGA_VERSION, true );
	}
	
	/* Load jquery plugins. */
	wp_enqueue_script( 'tiga-plugins', trailingslashit( TIGA_JS ) . 'plugins.js', array( 'jquery' ), TIGA_VERSION, true );
	
	/* Load jquery methods. */
	wp_enqueue_script( 'tiga-methods', trailingslashit( TIGA_JS ) . 'methods.js', array( 'jquery' ), TIGA_VERSION, true );

}

/**
 * Deregister default wp-pagenavi style
 *
 * @since 0.0.1
 */
function tiga_deregister_styles() {
	wp_deregister_style( 'wp-pagenavi' );
}

/**
 * Comment reply js
 *
 * @since 0.2
 */
function tiga_enqueue_comment_reply_script() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}

/**
 * Loads HTML5 Shiv.
 * 
 * @since 2.0
 */
function tiga_html5_script() {
?>
<!--[if lt IE 9]>
<script src="<?php echo trailingslashit( TIGA_JS ) . 'html5.js'; ?>"></script>
<script src="<?php echo trailingslashit( TIGA_JS ) . 'respond.js'; ?>"></script>
<![endif]-->
<?php
}