<?php
/**
 * Custom Option Framework file.
 *
 * @since      0.0.1
 * @author     Satrya <satrya@satrya.me>
 * @copyright  Copyright (c) 2012 - 2014, Satrya
 * @link       http://satrya.me/wordpress-themes/tiga/
 * @license    http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

function optionsframework_option_name() {

	/* This gets the theme name from the stylesheet. */
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings       = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;

	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the 
 * settings page and be saved in the database.
 *
 * @since 1.0
 */
function optionsframework_options() {
	
	/* Image path. */
	$layoutpath  =  trailingslashit( TIGA_IMAGE ) . 'layouts/';
	$patternpath =  trailingslashit( TIGA_IMAGE ) . 'bg/';
	
	/* Create an array of background options. */
	$background = array(
		'color'      => '',
		'image'      => '',
		'repeat'     => 'repeat',
		'position'   => 'top center',
		'attachment' =>'scroll' 
	);
	
	/* Create an array of select options. */
	$select = array(
		'enable'  => __( 'Enable' , 'tiga' ), 
		'disable' => __( 'Disable', 'tiga' ) 
	);

	/* Create an array of pattern options. */
	$patterns = array(
		'pattern-0'  => $patternpath . '0.png',
		'pattern-1'  => $patternpath . '1.png',
		'pattern-2'  => $patternpath . '2.png',
		'pattern-3'  => $patternpath . '3.png',
		'pattern-4'  => $patternpath . '4.png',
		'pattern-5'  => $patternpath . '5.jpg',
		'pattern-6'  => $patternpath . '6.jpg',
		'pattern-7'  => $patternpath . '7.png',
		'pattern-8'  => $patternpath . '8.png',
		'pattern-9'  => $patternpath . '9.png',
		'pattern-10' => $patternpath . '10.png'
	);
		
	/* Empty array */
	$options = array();

	$options[] = array( 
		'name' => __( 'Readme!', 'tiga' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => 'Important Note!',
		'desc' => '
			<p>Hello, it\'s been 8 months since I updated this theme. In the next version I will completely remove the theme settings and move it to the Theme Customizer. Please backup your website before updating to the next version.</p>
			<p>If you new to this theme, you don\'t need to worry about the update. Please just leave the theme settings with it\'s default settings. I will push the update next week.</p>
			<h4>Removed Settings in the next update</h4>
			<ol class="ol-decimal">
				<li>Header and footer scripts</li>
				<li>iFrame blocker</li>
				<li>Disable credit links, will changed with customizable footer text.</li>
				<li>Background patterns.</li>
				<li>Enable/disable author box, the author box automatically hidden if the user has not fill the descriptions on the profile page.</li>
			</ol>
			<p>Another note, for the header and footer scripts settings. I recommended you to install <a href="http://wordpress.org/plugins/header-footer/">http://wordpress.org/plugins/header-footer/</a> plugin if you need to add scripts to the header or footer of your site.</p>
			<p>Also, I will remove all custom widgets as well. It will be replaced by custom plugins.</p>
			<p>Thanks for your attention.</p>
			<p>Best Regards,<br>Satrya</p>
		',
		'type' => 'info'
	);
	
	/* Start GENERAL settings. */
	$options[] = array( 
		'name' => __( 'General', 'tiga' ),
		'type' => 'heading'
	);
								
	$options[] = array( 
		'name' => __( 'Custom Favicon', 'tiga' ),
		'desc' => __( 'Upload a favicon for your website, or specify the image address of your online favicon. (http://example.com/favicon.png)', 'tiga' ),
		'id'   => 'tiga_custom_favicon',
		'type' => 'upload'
	);
						
	$options[] = array( 
		'name'    => __( 'Iframe Blocker', 'tiga' ),
		'desc'    => __( 'Iframe blocker is for block iframe to your site such as google image.', 'tiga' ),
		'id'      => 'tiga_iframe_blocker',
		'std'     => 'disable',
		'type'    => 'select',
		'options' => $select
	);

	$options[] = array( 
		'name' => __( 'Disable credit links', 'tiga' ),
		'desc' => __( 'Are you sure want to disable the credit link for WordPress and theme author?', 'tiga' ),
		'id'   => 'tiga_credits',
		'type' => 'checkbox'
	);
						
	/* ============================== End General Settings ================================= */					
	$options[] = array( 
		'name' => __( 'Theme', 'tiga' ),
		'type' => 'heading'
	);
						
	$options[] = array( 
		'name'    => __( 'Global Layouts', 'tiga' ),
		'desc'    => __( 'Left content, right content or one column', 'tiga' ),
		'id'      => 'tiga_layouts',
		'std'     => 'lcontent',
		'type'    => 'images',
		'options' => array(
			'lcontent'  => $layoutpath . '2cr.png',
			'rcontent'  => $layoutpath . '2cl.png',
			'onecolumn' => $layoutpath . '1col.png',
		)
	);

	$options[] = array( 
		'name'    => __( 'Home Page Layouts', 'tiga' ),
		'desc'    => __( 'Two columns or one column', 'tiga' ),
		'id'      => 'tiga_home_layouts',
		'std'     => 'one-col',
		'type'    => 'images',
		'options' => array(
			'two-cols' => $layoutpath . 'l-mag.png',
			'one-col'  => $layoutpath . 'l-standard.png'
		)
	);
	
	$options[] = array( 
		'name'    => __( 'Background Pattern', 'tiga' ),
		'desc'    => __( 'Available background pattern to customize your site', 'tiga' ),
		'id'      => 'tiga_pattern',
		'std'     => 'pattern-0',
		'type'    => 'images',
		'options' => $patterns
	);
	
	/* ============================== End Theme Settings ================================= */	
	
	$options[] = array( 
		'name' => __( 'Typography', 'tiga' ),
		'type' => 'heading'
	);

	$options[] = array( 
		'name' => __( 'Disable custom typography', 'tiga' ),
		'desc' => __( 'Disable custom typography and use theme defaults.', 'tiga' ),
		'id'   => 'tiga_disable_typography',
		'std'  => true,
		'type' => 'checkbox' 
	);

	$options[] = array( 
		'name'    => __( 'Content typography', 'tiga' ),
		'desc'    => __( 'This font is used for content text.', 'tiga' ),
		'id'      => 'tiga_content_font',
		'class'   => 'hidden',
		'std'     => array('size' => '13px','face' => '"Open Sans", sans-serif', 'color' => '#333333' ),
		'type'    => 'typography',
		'options' => array(
			'sizes' => array( '12','13','14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24' ),
			'faces' => array(
				'"Open Sans", sans-serif' => 'Open Sans',
				'Arial, "Helvetica Neue", Helvetica, sans-serif' => 'Arial',
				'Georgia, Palatino, "Palatino Linotype", Times, "Times New Roman", serif' => 'Georgia',
				'Tahoma, Geneva, Verdana, sans-serif' => 'Tahoma',
				'"Helvetica Neue", Arial, Helvetica, sans-serif' => 'Helvetica',
				'Verdana, Geneva, sans-serif' => 'Verdana',
				'Times, "Times New Roman", Georgia, serif' => 'Times New Roman',
				'"Trebuchet MS", "Lucida Sans Unicode", "Lucida Grande", "Lucida Sans", Arial, sans-serif' => 'Trebuchet MS',
				'Cambria, Georgia, serif' => 'Cambria',
				'Calibri, Candara, Segoe, "Segoe UI", Optima, Arial, sans-serif' => 'Calibri'
			),
			'styles' => array( 'normal' => 'Normal', 'bold' => 'Bold' )
		)
	);

	$options[] = array( 
		'name'    => __( 'Content heading typography', 'tiga' ),
		'desc'    => __( 'Select the headline font (h1,h2,h3 etc)', 'tiga' ),
		'id'      => 'tiga_heading_font',
		'class'   => 'hidden',
		'std'     => array('size' => '13px','face' => '"Francois One", sans-serif', 'color' => '#333333' ),
		'type'    => 'typography',
		'options' => array(
			'sizes' => false,
			'faces' => array(
				'"Francois One", sans-serif' => 'Francois Regular',
				'Arial, "Helvetica Neue", Helvetica, sans-serif' => 'Arial',
				'Georgia, Palatino, "Palatino Linotype", Times, "Times New Roman", serif' => 'Georgia',
				'Tahoma, Geneva, Verdana, sans-serif' => 'Tahoma',
				'"Helvetica Neue", Arial, Helvetica, sans-serif' => 'Helvetica',
				'Verdana, Geneva, sans-serif' => 'Verdana',
				'Times, "Times New Roman", Georgia, serif' => 'Times New Roman',
				'"Trebuchet MS", "Lucida Sans Unicode", "Lucida Grande", "Lucida Sans", Arial, sans-serif' => 'Trebuchet MS',
				'Cambria, Georgia, serif' => 'Cambria',
				'Calibri, Candara, Segoe, "Segoe UI", Optima, Arial, sans-serif' => 'Calibri'
			),
			'styles' => array( 'normal' => 'Normal',  'bold' => 'Bold' )
		)
	);

	/* ============================== End Typography Settings ================================= */

	$options[] = array( 
		'name' => __( 'Page', 'tiga' ),
		'type' => 'heading'
	);
						
	$options[] = array( 
		'name' => __( 'Display author box', 'tiga' ),
		'desc' => __( 'Check this option if you want display the author box on single posts', 'tiga' ),
		'id'   => 'tiga_author_box',
		'type' => 'checkbox'
	);

	/* ============================== End Page Settings ================================= */

	$options[] = array( 
		'name' => __( 'Custom Code', 'tiga' ),
		'type' => 'heading'
	);

	$options[] = array( 
		'name' => __( 'Custom CSS', 'tiga' ),
		'desc' => __( 'Quickly add some CSS to your theme by adding it to this block.', 'tiga' ),
		'id'   => 'tiga_custom_css',
		'std'  => '',
		'type' => 'textarea'
	); 
						
	$options[] = array( 
		'name' => __( 'Header Code', 'tiga' ),
		'desc' => __( 'Add any custom script like the meta verification from various search engine. It will be inserted before the closing head tag of your theme', 'tiga' ),
		'id'   => 'tiga_header_code',
		'type' => 'textarea'
	); 	
						
	$options[] = array( 
		'name' => __( 'Footer Code', 'tiga' ),
		'desc' => __( 'Add your analytic code or you can add any custom script here. It will be inserted before the closing body tag of your theme', 'tiga' ),
		'id'   => 'tiga_footer_code',
		'type' => 'textarea'
	); 		 	 

	/* ============================== End Custom Code Settings ================================= */

	return $options;
	
}
?>